@@ -1,11 +1,16 @@
 package Net::DNS;
 
 #
-# $Id: DNS.pm 1442 2015-12-08 19:45:08Z willem $
+# $Id: DNS.pm 1465 2016-03-07 10:52:46Z willem $
 #
-use vars qw($VERSION $SVNVERSION);
-$VERSION    = '1.04';
-$SVNVERSION = (qw$LastChangedRevision: 1442 $)[1];
+BEGIN {
+	require 5.004_04;
+	require vars;
+	'vars'->import(qw($VERSION $SVNVERSION));
+	$VERSION    = '1.05';
+	$VERSION    = eval $VERSION;
+	$SVNVERSION = (qw$LastChangedRevision: 1465 $)[1];
+}
 
 
 =head1 NAME
@@ -29,7 +34,6 @@ details.
 =cut
 
 
-use 5.004_04;
 use strict;
 use integer;
 
@@ -37,7 +41,7 @@ use base qw(Exporter);
 use vars qw(@EXPORT);
 @EXPORT = qw(SEQUENTIAL UNIXTIME YYYYMMDDxx
 		yxrrset nxrrset yxdomain nxdomain rr_add rr_del
-		mx rrsort);
+		mx rr rrsort);
 
 
 use Net::DNS::RR;
@@ -49,6 +53,23 @@ use Net::DNS::Resolver;
 sub version { $VERSION; }
 
 
+#
+# rr()
+#
+# Usage:
+#	@rr = rr('example.com');
+#	@rr = rr('example.com', 'A', 'IN');
+#	@rr = rr($res, 'example.com' ... );
+#
+sub rr {
+	my ($arg1) = @_;
+	my $res = ref($arg1) ? shift : new Net::DNS::Resolver();
+
+	my $ans = $res->query(@_);
+	my @list = $ans ? $ans->answer : ();
+}
+
+
 #
 # mx()
 #
@@ -58,12 +79,9 @@ sub version { $VERSION; }
 #
 sub mx {
 	my ($arg1) = @_;
-	my $res = ref($arg1) ? shift : new Net::DNS::Resolver();
-
+	my @res = ( ref($arg1) ? shift : () );
 	my ( $name, @class ) = @_;
 
-	my $ans = $res->query( $name, 'MX', @class );
-
 	# This construct is best read backwards.
 	#
 	# First we take the answer section of the packet.
@@ -73,8 +91,7 @@ sub mx {
 	# Then we return the list.
 
 	my @list = sort { $a->preference <=> $b->preference }
-			grep $_->type eq 'MX', $ans->answer
-			if $ans;
+			grep $_->type eq 'MX', &rr( @res, $name, 'MX', @class );
 	return @list;
 }
 
@@ -246,6 +263,30 @@ See the manual pages listed above for other class-specific methods.
 
 Returns the version of Net::DNS.
 
+
+=head2 rr
+
+    # Use a default resolver -- can not get an error string this way.
+    use Net::DNS;
+    my @rr = rr("example.com");
+    my @rr = rr("example.com", "A");
+    my @rr = rr("example.com", "A", "IN");
+
+    # Use your own resolver object.
+    my $res = Net::DNS::Resolver->new;
+    my @rr  = rr($res, "example.com" ... );
+
+    my ($ptr) = rr("192.0.2.1");
+
+The rr() method provides simple RR lookup for scenarios where
+the full flexibility of Net::DNS is not required.
+
+Returns a list of L<Net::DNS::RR> objects for the specified name
+or an empty list if the query failed or no record was found.
+
+See L</EXAMPLES> for more complete examples.
+
+
 =head2 mx
 
     # Use a default resolver -- can not get an error string this way.
@@ -253,9 +294,8 @@ Returns the version of Net::DNS.
     my @mx = mx("example.com");
 
     # Use your own resolver object.
-    use Net::DNS;
     my $res = Net::DNS::Resolver->new;
-    my @mx = mx($res, "example.com");
+    my @mx  = mx($res, "example.com");
 
 Returns a list of L<Net::DNS::RR::MX> objects representing the MX
 records for the specified name.
@@ -264,9 +304,6 @@ Returns an empty list if the query failed or no MX record was found.
 
 This method does not look up A records; it only performs MX queries.
 
-See L</EXAMPLES> for a more complete example.
-
-
 
 =head1 Dynamic DNS Update Support
 
@@ -349,19 +386,19 @@ be created.
 =head2 rr_del
 
 Use this method to delete RRs from a zone.  There are three forms:
-delete an RRset, delete all RRsets, and delete an RR.
-
-    # Delete an RRset.
-    $packet->push(update => rr_del("host.example.com A"));
-
-Meaning:  Delete all RRs having the specified name and type.
+delete all RRsets, delete an RRset, and delete a specific RR.
 
     # Delete all RRsets.
     $packet->push(update => rr_del("host.example.com"));
 
 Meaning:  Delete all RRs having the specified name.
 
-    # Delete an RR.
+    # Delete an RRset.
+    $packet->push(update => rr_del("host.example.com A"));
+
+Meaning:  Delete all RRs having the specified name and type.
+
+    # Delete a specific RR.
     $packet->push(update => rr_del("host.example.com A 10.1.2.3"));
 
 Meaning:  Delete all RRs having the specified name, type, and data.
@@ -412,7 +449,7 @@ method. See Net::DNS::RR for details.
 
 =head2 rrsort()
 
-    use Net::DNS 0.55;
+    use Net::DNS;
 
     my @sorted = rrsort( $rrtype, $attribute, @rr_array );
 
