@@ -1,10 +1,10 @@
 package Net::DNS::Domain;
 
 #
-# $Id: Domain.pm 1406 2015-10-05 08:25:49Z willem $
+# $Id: Domain.pm 1456 2016-02-17 13:34:00Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1406 $)[1];
+$VERSION = (qw$LastChangedRevision: 1456 $)[1];
 
 
 =head1 NAME
@@ -54,7 +54,7 @@ use constant UTF8 => ref eval {
 	LIBUTF8 && Encode::find_encoding('utf8');		# encoding object
 };
 
-use constant LIBIDN => UTF8 && defined eval { require Net::LibIDN; };
+use constant LIBIDN => UTF8 && defined eval 'require Net::LibIDN';
 
 
 # perlcc: address of encoding objects must be determined at runtime
