@@ -1,10 +1,10 @@
 package Net::DNS::RR::LP;
 
 #
-# $Id: LP.pm 1390 2015-09-11 11:42:11Z willem $
+# $Id: LP.pm 1406 2015-10-05 08:25:49Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1390 $)[1];
+$VERSION = (qw$LastChangedRevision: 1406 $)[1];
 
 
 use strict;
@@ -65,7 +65,7 @@ sub target {
 	my $self = shift;
 
 	$self->{target} = new Net::DNS::DomainName(shift) if scalar @_;
-	$self->{target}->name if defined wantarray && $self->{target};
+	$self->{target}->name if $self->{target};
 }
 
 
