@@ -1,10 +1,10 @@
 package Net::DNS::RR::RRSIG;
 
 #
-# $Id: RRSIG.pm 1392 2015-09-13 16:30:51Z willem $
+# $Id: RRSIG.pm 1456 2016-02-17 13:34:00Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1392 $)[1];
+$VERSION = (qw$LastChangedRevision: 1456 $)[1];
 
 
 use strict;
@@ -27,15 +27,15 @@ use Net::DNS::Parameters;
 
 use constant DEBUG => 0;
 
-use constant UTIL => defined eval { require Scalar::Util; };
+use constant UTIL => defined eval 'require Scalar::Util';
 
-use constant PRIVATE => defined eval { require Net::DNS::SEC::Private; };
+use constant PRIVATE => defined eval 'require Net::DNS::SEC::Private';
 
-use constant DSA => scalar eval { require Net::DNS::SEC::DSA; };
-use constant RSA => scalar eval { require Net::DNS::SEC::RSA; };
+use constant DSA => defined eval 'require Net::DNS::SEC::DSA';
+use constant RSA => defined eval 'require Net::DNS::SEC::RSA';
 
-use constant ECDSA => scalar eval { require Net::DNS::SEC::ECDSA; };
-use constant GOST  => scalar eval { require Net::DNS::SEC::ECCGOST; };
+use constant ECDSA => defined eval 'require Net::DNS::SEC::ECDSA';
+use constant GOST  => defined eval 'require Net::DNS::SEC::ECCGOST';
 
 use constant DNSSEC => PRIVATE && ( RSA || DSA || ECDSA || GOST );
 
@@ -233,7 +233,7 @@ sub signame {
 	my $self = shift;
 
 	$self->{signame} = new Net::DNS::DomainName(shift) if scalar @_;
-	$self->{signame}->name if defined wantarray && $self->{signame};
+	$self->{signame}->name if $self->{signame};
 }
 
 
@@ -420,6 +420,10 @@ my $y1998 = timegm( 0, 0, 0, 1, 0, 1998 );
 my $y2026 = timegm( 0, 0, 0, 1, 0, 2026 );
 my $y2082 = $y2026 << 1;
 my $y2054 = $y2082 - $y1998;
+my $m2026 = int( 0x80000000 - $y2026 );
+my $m2054 = int( 0x80000000 - $y2054 );
+my $t2082 = int( $y2082 & 0x7FFFFFFF );
+my $t2100 = 1960058752;
 
 sub _string2time {			## parse time specification string
 	my $arg = shift;
@@ -440,16 +444,26 @@ sub _string2time {			## parse time specification string
 sub _time2string {			## format time specification string
 	my $arg = shift;
 	croak 'undefined time' unless defined $arg;
-	unless ( $arg < 0 ) {
-		my ( $yy, $mm, @dhms ) = reverse( ( gmtime $arg )[0 .. 5] );
-		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1900, $mm + 1, @dhms;
-	} elsif ( $arg > $y2082 ) {
-		$arg += 86400 unless $arg < $y2054 + 1456704000;      # expunge 29 Feb 2100
-		my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $arg - $y2054 ) )[0 .. 5] );
-		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1984, $mm + 1, @dhms;
+	my $ls31 = int( $arg & 0x7FFFFFFF );
+	if ( $arg & 0x80000000 ) {
+
+		if ( $ls31 > $t2082 ) {
+			$ls31 += 86400 unless $ls31 < $t2100;	# expunge 29 Feb 2100
+			my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 + $m2054 ) )[0 .. 5] );
+			return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1984, $mm + 1, @dhms;
+		}
+
+		my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 + $m2026 ) )[0 .. 5] );
+		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1956, $mm + 1, @dhms;
+
+
+	} elsif ( $ls31 > $y2026 ) {
+		my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $ls31 - $y2026 ) )[0 .. 5] );
+		return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1956, $mm + 1, @dhms;
 	}
-	my ( $yy, $mm, @dhms ) = reverse( ( gmtime( $arg - $y2026 ) )[0 .. 5] );
-	return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1956, $mm + 1, @dhms;
+
+	my ( $yy, $mm, @dhms ) = reverse( ( gmtime $ls31 )[0 .. 5] );
+	return sprintf '%d%02d%02d%02d%02d%02d', $yy + 1900, $mm + 1, @dhms;
 }
 
 
@@ -583,8 +597,8 @@ __END__
 
     use Net::DNS::SEC;
     $sigrr = create Net::DNS::RR::RRSIG( \@rrset, $keypath,
-					sigex => 20151231010101
-					sigin => 20151201010101
+					sigex => 20161231010101
+					sigin => 20161201010101
 					);
 
     $sigrr->verify( \@rrset, $keyrr ) || die $sigrr->vrfyerrstr;
@@ -708,8 +722,8 @@ Create a signature over a RR set.
     $sigrr = create Net::DNS::RR::RRSIG( \@rrsetref, $keypath );
 
     $sigrr = create Net::DNS::RR::RRSIG( \@rrsetref, $keypath,
-					sigex => 20151231010101
-					sigin => 20151201010101
+					sigex => 20161231010101
+					sigin => 20161201010101
 					);
     $sigrr->print;
 
@@ -735,8 +749,8 @@ containing the private key as generated by dnssec-keygen.
 The optional remaining arguments consist of ( name => value ) pairs
 as follows:
 
-	sigex  => 20151231010101,	# signature expiration
-	sigin  => 20151201010101,	# signature inception
+	sigex  => 20161231010101,	# signature expiration
+	sigin  => 20161201010101,	# signature inception
 	sigval => 30,			# validity window (days)
 	ttl    => 3600			# TTL
 
