@@ -1,10 +1,10 @@
 package Net::DNS::ZoneFile;
 
 #
-# $Id: ZoneFile.pm 1408 2015-10-06 20:35:56Z willem $
+# $Id: ZoneFile.pm 1464 2016-03-03 13:00:22Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1408 $)[1];
+$VERSION = (qw$LastChangedRevision: 1464 $)[1];
 
 
 =head1 NAME
@@ -46,12 +46,12 @@ automatically to all subsequent records.
 use strict;
 use integer;
 use Carp;
+use FileHandle;
 
-require FileHandle;
+use constant PERLIO => defined eval 'require PerlIO';
 
-use Net::DNS;
-
-use constant PERLIO => defined eval { require PerlIO; };
+require Net::DNS::Domain;
+require Net::DNS::RR;
 
 
 =head1 METHODS
@@ -273,7 +273,7 @@ sub _read {
 
 	use overload ( '<>' => 'readline' );
 
-	use constant OVERLOAD_OK => scalar eval { no integer; $] > 5.006; };
+	use constant OVERLOAD_OK => scalar eval 'no integer; $] > 5.006';
 
 	sub new {
 		my $self = bless {}, shift;
@@ -348,7 +348,7 @@ sub parse {
 
 	use overload ( '<>' => 'readline' );
 
-	use constant OVERLOAD_OK => scalar eval { no integer; $] > 5.006; };
+	use constant OVERLOAD_OK => scalar eval 'no integer; $] > 5.006';
 
 	sub new {
 		my $self = bless {}, shift;
@@ -487,7 +487,7 @@ sub _getline {				## get line from current source
 		} elsif (/^\$TTL/) {				# directive
 			my ( $keyword, $ttl, @etc ) = split;
 			die '$TTL incomplete' unless defined $ttl;
-			$self->{TTL} = new Net::DNS::RR(". $ttl IN A")->ttl;
+			$self->{TTL} = Net::DNS::RR::ttl( {}, $ttl );
 
 		} else {					# unrecognised
 			my ($keyword) = split;
